diff --git a/BizHawk.Client.EmuHawk/BizHawk.Client.EmuHawk.csproj b/BizHawk.Client.EmuHawk/BizHawk.Client.EmuHawk.csproj
index bd1ad1cbcc..484ec23d18 100644
--- a/BizHawk.Client.EmuHawk/BizHawk.Client.EmuHawk.csproj
+++ b/BizHawk.Client.EmuHawk/BizHawk.Client.EmuHawk.csproj
@@ -1479,6 +1479,8 @@
     <None Include="config\ControllerImages\GENController.png" />
   </ItemGroup>
   <ItemGroup>
+    <None Include="images\user_blue_small.png" />
+    <None Include="images\user_blue.ico" />
     <None Include="images\tastudio\ts_v_piano_19_green_blue.png" />
     <None Include="images\tastudio\ts_v_piano_19_green.png" />
     <None Include="images\tastudio\ts_v_piano_19_blue.png" />
diff --git a/BizHawk.Client.EmuHawk/MainForm.Designer.cs b/BizHawk.Client.EmuHawk/MainForm.Designer.cs
index 2d90bf9487..7159ced8e4 100644
--- a/BizHawk.Client.EmuHawk/MainForm.Designer.cs
+++ b/BizHawk.Client.EmuHawk/MainForm.Designer.cs
@@ -1417,7 +1417,7 @@
 			// 
 			// ProfilesMenuItem
 			// 
-			this.ProfilesMenuItem.Image = global::BizHawk.Client.EmuHawk.Properties.Resources.user_blue;
+			this.ProfilesMenuItem.Image = global::BizHawk.Client.EmuHawk.Properties.Resources.user_blue_small;
 			this.ProfilesMenuItem.Name = "ProfilesMenuItem";
 			this.ProfilesMenuItem.Size = new System.Drawing.Size(169, 22);
 			this.ProfilesMenuItem.Text = "&Profiles...";
@@ -2879,7 +2879,7 @@
 			// 
 			this.ProfileFirstBootLabel.AutoToolTip = true;
 			this.ProfileFirstBootLabel.DisplayStyle = System.Windows.Forms.ToolStripItemDisplayStyle.Image;
-			this.ProfileFirstBootLabel.Image = global::BizHawk.Client.EmuHawk.Properties.Resources.user_blue;
+			this.ProfileFirstBootLabel.Image = global::BizHawk.Client.EmuHawk.Properties.Resources.user_blue_small;
 			this.ProfileFirstBootLabel.Name = "ProfileFirstBootLabel";
 			this.ProfileFirstBootLabel.Size = new System.Drawing.Size(16, 17);
 			this.ProfileFirstBootLabel.Text = "ProfileFirstBootLabel";
diff --git a/BizHawk.Client.EmuHawk/Properties/Resources.resx b/BizHawk.Client.EmuHawk/Properties/Resources.resx
index 8c5327e200..209ed977aa 100644
--- a/BizHawk.Client.EmuHawk/Properties/Resources.resx
+++ b/BizHawk.Client.EmuHawk/Properties/Resources.resx
@@ -939,9 +939,6 @@
   <data name="thumbsdown" type="System.Resources.ResXFileRef, System.Windows.Forms">
     <value>..\images\thumbsdown.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a</value>
   </data>
-  <data name="user_blue" type="System.Resources.ResXFileRef, System.Windows.Forms">
-    <value>..\images\user_blue.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a</value>
-  </data>
   <data name="YellowDown" type="System.Resources.ResXFileRef, System.Windows.Forms">
     <value>..\images\YellowDown.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a</value>
   </data>
@@ -1461,4 +1458,10 @@
   <data name="ts_v_piano_19_green_blue" type="System.Resources.ResXFileRef, System.Windows.Forms">
     <value>..\images\tastudio\ts_v_piano_19_green_blue.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a</value>
   </data>
+  <data name="user_blue" type="System.Resources.ResXFileRef, System.Windows.Forms">
+    <value>..\images\user_blue.ico;System.Drawing.Icon, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a</value>
+  </data>
+  <data name="user_blue_small" type="System.Resources.ResXFileRef, System.Windows.Forms">
+    <value>..\images\user_blue_small.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a</value>
+  </data>
 </root>
\ No newline at end of file
diff --git a/BizHawk.Client.EmuHawk/Properties/Resources.Designer.cs b/BizHawk.Client.EmuHawk/Properties/Resources.Designer.cs
index 239999da8e..56ed2747fd 100644
--- a/BizHawk.Client.EmuHawk/Properties/Resources.Designer.cs
+++ b/BizHawk.Client.EmuHawk/Properties/Resources.Designer.cs
@@ -2990,11 +2990,21 @@ namespace BizHawk.Client.EmuHawk.Properties {
         }
         
         /// <summary>
         ///   Looks up a localized resource of type System.Drawing.Bitmap.
         /// </summary>
-        internal static System.Drawing.Bitmap user_blue {
+        internal static System.Drawing.Icon user_blue {
             get {
                 object obj = ResourceManager.GetObject("user_blue", resourceCulture);
+                return ((System.Drawing.Icon)(obj));
+            }
+        }
+        
+        /// <summary>
+        ///   Looks up a localized resource of type System.Drawing.Bitmap.
+        /// </summary>
+        internal static System.Drawing.Bitmap user_blue_small {
+            get {
+                object obj = ResourceManager.GetObject("user_blue_small", resourceCulture);
                 return ((System.Drawing.Bitmap)(obj));
             }
         }
@@ -2990,11 +2990,21 @@ namespace BizHawk.Client.EmuHawk.Properties {
         
         /// <summary>
-        ///   Looks up a localized resource of type System.Drawing.Bitmap.
+        ///   Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
         /// </summary>
diff --git a/BizHawk.Client.EmuHawk/images/user_blue.ico b/BizHawk.Client.EmuHawk/images/user_blue.ico
index 051b9fe26d..98b6699fd7 100644
Binary files a/BizHawk.Client.EmuHawk/images/user_blue.ico and b/BizHawk.Client.EmuHawk/images/user_blue.ico differ
diff --git a/BizHawk.Client.EmuHawk/images/user_blue.png b/BizHawk.Client.EmuHawk/images/user_blue.png
index cd58cda52e..0c76dd066e 100644
Binary files a/BizHawk.Client.EmuHawk/images/user_blue.png and b/BizHawk.Client.EmuHawk/images/user_blue.png differ
diff --git a/BizHawk.Client.EmuHawk/images/user_blue_small.png b/BizHawk.Client.EmuHawk/images/user_blue_small.png
new file mode 100644
index 0000000000..4753eb6264
Binary files /dev/null and b/BizHawk.Client.EmuHawk/images/user_blue_small.png differ